package com.zilber.boot.framework.web.service;


import com.zilber.boot.Constants.Constants;
import com.zilber.boot.Constants.UserConstants;
import com.zilber.boot.framework.manager.AsyncManager;
import com.zilber.boot.framework.manager.factory.AsyncFactory;
import com.zilber.boot.system.pojo.SysUser;
import com.zilber.boot.system.service.ISysUserService;
import com.zilber.boot.utils.MessageUtils;
import com.zilber.boot.utils.RedisCache;
import com.zilber.boot.utils.SecurityUtils;
import com.zilber.boot.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * 注册校验方法
 *
 * @author lsc
 */
@Component
public class SysRegisterService
{
    @Autowired
    private ISysUserService userService;

    @Autowired
    private RedisCache redisCache;

    /**
     * 注册
     */
    public String register(SysUser sysUser)
    {
        String msg = "", username = sysUser.getUserName(), password = sysUser.getPassword();
        SysUser user = new SysUser();
        sysUser.setUserName(username);

        if (StringUtils.isEmpty(username))
        {
            msg = "用户名不能为空";
        }
        else if (StringUtils.isEmpty(password))
        {
            msg = "用户密码不能为空";
        }
        else if (username.length() < UserConstants.USERNAME_MIN_LENGTH
                || username.length() > UserConstants.USERNAME_MAX_LENGTH)
        {
            msg = "账户长度必须在2到20个字符之间";
        }
        else if (password.length() < UserConstants.PASSWORD_MIN_LENGTH
                || password.length() > UserConstants.PASSWORD_MAX_LENGTH)
        {
            msg = "密码长度必须在5到20个字符之间";
        }
        else if (UserConstants.NOT_UNIQUE.equals(userService.checkUserNameUnique(sysUser)))
        {
            msg = "保存用户'" + username + "'失败，注册账号已存在";
        }
        else
        {
            user.setNickName(username);
            user.setPassword(SecurityUtils.encryptPassword(password));
            boolean regFlag = userService.registerUser(user);
            if (!regFlag)
            {
                msg = "注册失败,请联系系统管理人员";
            }
            else
            {
                AsyncManager.me().execute(AsyncFactory.recordLogininfor(username, Constants.REGISTER, MessageUtils.message("user.register.success")));
            }
        }
        return msg;
    }

}
