package com.zilber.boot.intelligencesite.controller;


import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.zilber.boot.annotation.Anonymous;
import com.zilber.boot.commoncontroller.BaseController;
import com.zilber.boot.intelligencesite.entity.IConstructionReport;
import com.zilber.boot.intelligencesite.service.IIConstructionReportService;
import com.zilber.boot.utils.AjaxResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 施工报告 前端控制器
 * </p>
 *
 * @author lsc
 * @since 2025-05-06
 */
@RestController
@RequestMapping("/iconstructionreport")
@Api(tags = "施工报告")
public class IConstructionReportController extends BaseController {


    @Resource
    private IIConstructionReportService iiConstructionReportService;


    @GetMapping("/list")
    @ApiOperation(value="分页查询",notes="分页查询")
    @ResponseBody
    public AjaxResult queryList(IConstructionReport iConstructionReport, @RequestParam(defaultValue = "1") Integer pageNo,
                                @RequestParam(defaultValue = "10") Integer pageSize) {
        PageHelper.startPage(pageNo, pageSize);
        List<IConstructionReport> iConstructionReports = iiConstructionReportService.queryList(iConstructionReport);
        PageInfo<IConstructionReport> page = new PageInfo<>(iConstructionReports);
        return AjaxResult.success(page);
    }

    /***
     * 查询单个
     */
    @GetMapping("/getById")
    @ApiOperation("查询单个")
    public AjaxResult getById(Integer id) {
        return AjaxResult.success(iiConstructionReportService.getById(id));
    }


    @PostMapping("/add")
    @ApiOperation("增加")
    public AjaxResult add(@RequestBody IConstructionReport iConstructionReport) {
        iConstructionReport.setCreateTime(new Date());
        iConstructionReport.setCreator(getUsername());
        return AjaxResult.success(iiConstructionReportService.save(iConstructionReport));
    }


    @PutMapping("/update")
    @ApiOperation("修改")
    @Anonymous
    public AjaxResult update(@RequestBody @Validated IConstructionReport iConstructionReport) {
        iiConstructionReportService.updateById(iConstructionReport);
        return AjaxResult.success();
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除")
    public AjaxResult delete(Integer id) {
        return AjaxResult.success(iiConstructionReportService.removeById(id));
    }

}
