package com.zilber.boot.intelligencesite.controller;


import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.zilber.boot.commoncontroller.BaseController;
import com.zilber.boot.intelligencesite.entity.IProductionPlan;
import com.zilber.boot.intelligencesite.service.IIProductionPlanService;
import com.zilber.boot.utils.AjaxResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 生产计划表 前端控制器
 * </p>
 *
 * @author lsc
 * @since 2025-05-06
 */
@RestController
@RequestMapping("/iproductionplan")
@Api(tags = "生产计划")
public class IProductionPlanController extends BaseController {

    @Resource
    private IIProductionPlanService iiProductionPlanService;


    @GetMapping("/list")
    @ApiOperation(value="分页查询",notes="分页查询")
    @ResponseBody
    public AjaxResult queryList(IProductionPlan iProductionPlan, @RequestParam(defaultValue = "1") Integer pageNo,
                                @RequestParam(defaultValue = "10") Integer pageSize) {
        PageHelper.startPage(pageNo, pageSize);
        List<IProductionPlan> iProductionPlans = iiProductionPlanService.queryList(iProductionPlan);
        PageInfo<IProductionPlan> page = new PageInfo<>(iProductionPlans);
        return AjaxResult.success(page);
    }

    /***
     * 查询单个
     */
    @GetMapping("/getById")
    @ApiOperation("查询单个")
    public AjaxResult getById(Integer id) {
        return AjaxResult.success(iiProductionPlanService.getById(id));
    }


    @PostMapping("/add")
    @ApiOperation("增加")
    public AjaxResult add(@RequestBody IProductionPlan iProductionPlan) {
        iProductionPlan.setCreateTime(new Date());
        iProductionPlan.setCreator(getUsername());
        return AjaxResult.success(iiProductionPlanService.save(iProductionPlan));
    }


    @PutMapping("/update")
    @ApiOperation("修改")
    public AjaxResult update(@RequestBody @Validated IProductionPlan iProductionPlan) {
        iiProductionPlanService.updateById(iProductionPlan);
        return AjaxResult.success();
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除")
    public AjaxResult delete(Integer id) {
        return AjaxResult.success(iiProductionPlanService.removeById(id));
    }


    @GetMapping("/statistics")
    @ApiOperation("自动统计计划进度与实际进度")
    public AjaxResult statistics() {
        return AjaxResult.success(iiProductionPlanService.statistics());
    }

    @GetMapping("/querywarn")
    @ApiOperation("预警提示")
    public AjaxResult querywarn(Integer day) {
        return AjaxResult.success(iiProductionPlanService.querywarn(day));
    }

}
