package com.zilber.boot.intelligencesite.controller;


import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.zilber.boot.annotation.Anonymous;
import com.zilber.boot.commoncontroller.BaseController;
import com.zilber.boot.intelligencesite.entity.IResourceSchedule;
import com.zilber.boot.intelligencesite.service.IIResourceScheduleService;
import com.zilber.boot.utils.AjaxResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 资源调度表 前端控制器
 * </p>
 *
 * @author lsc
 * @since 2025-05-06
 */
@RestController
@RequestMapping("/iresourceschedule")
@Api(tags = "资源调度")
public class IResourceScheduleController extends BaseController {
    @Resource
    private IIResourceScheduleService iiResourceScheduleService;


    @GetMapping("/list")
    @ApiOperation(value="分页查询",notes="分页查询")
    @ResponseBody
    public AjaxResult queryList(IResourceSchedule iResourceSchedule, @RequestParam(defaultValue = "1") Integer pageNo,
                                @RequestParam(defaultValue = "10") Integer pageSize) {
        PageHelper.startPage(pageNo, pageSize);
        List<IResourceSchedule> iResourceSchedules = iiResourceScheduleService.queryList(iResourceSchedule);
        PageInfo<IResourceSchedule> page = new PageInfo<>(iResourceSchedules);
        return AjaxResult.success(page);
    }

    /***
     * 查询单个
     */
    @GetMapping("/getById")
    @ApiOperation("查询单个")
    public AjaxResult getById(Integer id) {
        return AjaxResult.success(iiResourceScheduleService.getById(id));
    }


    @PostMapping("/add")
    @ApiOperation("增加")
    public AjaxResult add(@RequestBody IResourceSchedule iResourceSchedule) {
        iResourceSchedule.setCreateTime(new Date());
        iResourceSchedule.setCreator(getUsername());
        return AjaxResult.success(iiResourceScheduleService.save(iResourceSchedule));
    }


    @PutMapping("/update")
    @ApiOperation("修改")
    @Anonymous
    public AjaxResult update(@RequestBody @Validated IResourceSchedule iResourceSchedule) {
        iiResourceScheduleService.updateById(iResourceSchedule);
        return AjaxResult.success();
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除")
    public AjaxResult delete(Integer id) {
        return AjaxResult.success(iiResourceScheduleService.removeById(id));
    }

}
