package com.zilber.boot.intelligencesite.service.impl;

import com.zilber.boot.intelligencesite.entity.IProductionPlan;
import com.zilber.boot.intelligencesite.entity.IProgress;
import com.zilber.boot.intelligencesite.mapper.IProductionPlanMapper;
import com.zilber.boot.intelligencesite.mapper.IProgressMapper;
import com.zilber.boot.intelligencesite.service.IIProductionPlanService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zilber.boot.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.*;

/**
 * <p>
 * 生产计划表 服务实现类
 * </p>
 *
 * @author lsc
 * @since 2025-05-06
 */
@Service
public class IProductionPlanServiceImpl extends ServiceImpl<IProductionPlanMapper, IProductionPlan> implements IIProductionPlanService {

    @Resource
    private IProductionPlanMapper iProductionPlanMapper;
    @Resource
    private IProgressMapper iProgressMapper;



    @Override
    public List<IProductionPlan> queryList(IProductionPlan iProductionPlan) {
        return iProductionPlanMapper.queryList(iProductionPlan);
    }

    @Override
    public Map<String, Object> statistics() {
        List<IProductionPlan> iProductionPlans = iProductionPlanMapper.queryList(null);
        List<String> namelist=new ArrayList<>();
        List<BigDecimal> planlist=new ArrayList<>();
        List<Long> actuallist=new ArrayList<>();
        for (IProductionPlan iProductionPlan : iProductionPlans) {
            //获取每个计划时间差（结束时间-开始时间）
            //long datePoorByDay = DateUtils.getDatePoorByDay(iProductionPlan.getEndTime(), iProductionPlan.getStartTime());
            //获取每个计划每天应完成的百分比
            BigDecimal daypercent = new BigDecimal(1).divide(new BigDecimal(iProductionPlan.getDuration()),2,BigDecimal.ROUND_HALF_UP).multiply(new BigDecimal(100));
            //获取当前日期，减去开始日期，乘以每个计划每天应完成的百分比，算出截止今天应该完成的百分比
            BigDecimal currentpercent = BigDecimal.valueOf(DateUtils.getDatePoorByDay(new Date(), iProductionPlan.getStartTime())).multiply(daypercent);
            if (DateUtils.getDatePoorByDay(new Date(), iProductionPlan.getEndTime()) > 0) {
                currentpercent = BigDecimal.valueOf(100);
            }
            planlist.add(currentpercent);
            namelist.add(iProductionPlan.getPlanName());
            //查询计划实际填报情况
            List<IProgress> progresseslist = iProgressMapper.queryList(new IProgress().setPlanId(iProductionPlan.getId()));
            long total = progresseslist.stream().mapToLong(IProgress::getDayProgress).sum();
            actuallist.add(total);
        }
        Map<String, Object> result = new HashMap<>();
        result.put("namelist",namelist);
        result.put("planlist",planlist);
        result.put("actuallist",actuallist);
        return result;
    }

    @Override
    public List<IProductionPlan> querywarn(Integer day) {
        List<IProductionPlan> iProductionPlans = iProductionPlanMapper.queryList(null);
        List<IProductionPlan> newiProductionPlans=new ArrayList<>();
        for (IProductionPlan iProductionPlan : iProductionPlans) {
            if (DateUtils.getDatePoorByDay(new Date(), iProductionPlan.getEndTime()) > day) {
                newiProductionPlans.add(iProductionPlan);
            }
        }
        return newiProductionPlans;
    }
}
