package com.zilber.boot.monitor;


import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.zilber.boot.annotation.Log;
import com.zilber.boot.commoncontroller.BaseController;
import com.zilber.boot.enums.BusinessType;
import com.zilber.boot.framework.web.service.SysPasswordService;
import com.zilber.boot.system.pojo.SysLogininfor;
import com.zilber.boot.system.service.ISysLogininforService;
import com.zilber.boot.utils.AjaxResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import java.util.List;

/**
 * 系统访问记录
 *
 * @author lsc
 */
@RestController
@RequestMapping("/monitor/logininfor")
@Api(tags = "系统访问记录")
public class SysLogininforController extends BaseController
{
    @Autowired
    private ISysLogininforService logininforService;

    @Autowired
    private SysPasswordService passwordService;

    @PreAuthorize("@ss.hasPermi('monitor:logininfor:list')")
    @ApiOperation(value="系统访问记录",notes="系统访问记录")
    @GetMapping("/list")
    public AjaxResult list(SysLogininfor logininfor, @RequestParam(defaultValue = "1") Integer pageNo,
                           @RequestParam(defaultValue = "10") Integer pageSize)
    {
        PageHelper.startPage(pageNo, pageSize);
        List<SysLogininfor> list = logininforService.selectLogininforList(logininfor);
        PageInfo<SysLogininfor> page = new PageInfo<>(list);
        return AjaxResult.success(page);
    }


    @PreAuthorize("@ss.hasPermi('monitor:logininfor:remove')")
    @Log(title = "登录日志", businessType = BusinessType.DELETE)
    @ApiOperation(value="删除登录日志",notes="删除登录日志")
    @DeleteMapping("/remove")
    public AjaxResult remove(Long[] infoIds)
    {
        return toAjax(logininforService.deleteLogininforByIds(infoIds));
    }

    @PreAuthorize("@ss.hasPermi('monitor:logininfor:remove')")
    @Log(title = "登录日志", businessType = BusinessType.CLEAN)
    @ApiOperation(value="清空系统登录日志",notes="清空系统登录日志")
    @DeleteMapping("/clean")
    public AjaxResult clean()
    {
        logininforService.cleanLogininfor();
        return success();
    }

    @PreAuthorize("@ss.hasPermi('monitor:logininfor:unlock')")
    @Log(title = "账户解锁", businessType = BusinessType.OTHER)
    @GetMapping("/unlock/{userName}")
    public AjaxResult unlock(@PathVariable("userName") String userName)
    {
        passwordService.clearLoginRecordCache(userName);
        return success();
    }
}
