package com.zilber.boot.monitor;


import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.zilber.boot.annotation.Log;
import com.zilber.boot.commoncontroller.BaseController;
import com.zilber.boot.enums.BusinessType;
import com.zilber.boot.system.pojo.SysOperLog;
import com.zilber.boot.system.service.ISysOperLogService;
import com.zilber.boot.utils.AjaxResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import java.util.List;


/**
 * 操作日志记录
 *
 * @author lsc
 */
@RestController
@RequestMapping("/monitor/operlog")
@Api(tags = "操作日志记录")
public class SysOperlogController extends BaseController
{
    @Autowired
    private ISysOperLogService operLogService;

    @PreAuthorize("@ss.hasPermi('monitor:operlog:list')")
    @GetMapping("/list")
    @ApiOperation(value="操作日志记录列表",notes="操作日志记录列表")
    public AjaxResult list(SysOperLog operLog, @RequestParam(defaultValue = "1") Integer pageNo,
                           @RequestParam(defaultValue = "10") Integer pageSize)
    {
        PageHelper.startPage(pageNo, pageSize);
        List<SysOperLog> list = operLogService.selectOperLogList(operLog);
        PageInfo<SysOperLog> page = new PageInfo<>(list);
        return AjaxResult.success(page);
    }


    @PreAuthorize("@ss.hasPermi('monitor:operlog:remove')")
    @Log(title = "操作日志", businessType = BusinessType.DELETE)
    @ApiOperation(value="批量删除系统操作日志",notes="批量删除系统操作日志")
    @DeleteMapping("/remove")
    public AjaxResult remove(Long[] operIds)
    {
        return toAjax(operLogService.deleteOperLogByIds(operIds));
    }

    @PreAuthorize("@ss.hasPermi('monitor:operlog:remove')")
    @Log(title = "操作日志", businessType = BusinessType.CLEAN)
    @ApiOperation(value="清空操作日志",notes="清空操作日志")
    @DeleteMapping("/clean")
    public AjaxResult clean()
    {
        operLogService.cleanOperLog();
        return AjaxResult.success();
    }
}
