package com.zilber.boot.system.controller;

import com.zilber.boot.annotation.Anonymous;
import com.zilber.boot.system.pojo.SysDictionary;
import com.zilber.boot.system.service.ISysDictionaryService;
import com.zilber.boot.utils.AjaxResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 数据字典Controller
 */
@RestController
@RequestMapping("/system/dictionary")
@Api(tags = "数据字典管理")
@Anonymous
public class SysDictionaryController {
    @Autowired
    private ISysDictionaryService sysDictionaryService;

    /**
     * 获取数据字典列表(分页查询)
     * @param sysDictionary
     * @return
     */
    //@PreAuthorize("@ss.hasPermi('system:dictionary:list')")
    @ApiOperation(value="获取数据字典列表",notes="获取数据字典列表")
    @GetMapping("/list")
    public AjaxResult list(SysDictionary sysDictionary) {
      /*  PageHelper pageHelper = new PageHelper();
        pageHelper.startPage(pageNo, pageSize);*/
        if(sysDictionary.getParentId() == null){
            sysDictionary.setParentId(0L);
        }
        List<SysDictionary> list = sysDictionaryService.getList(sysDictionary);
        return AjaxResult.success(list);
    }


    @ApiOperation("新增数据字典数据")
    @PostMapping
    public AjaxResult add(@RequestBody SysDictionary sysDictionary){
        try {
            if(sysDictionaryService.addDict(sysDictionary)){
                return AjaxResult.success();
            }else {
                return AjaxResult.error();
            }
        }catch (Exception e){
            e.printStackTrace();
            return AjaxResult.error(e.getMessage());
        }
    }

    @ApiOperation("修改数据字典数据")
    @PutMapping
    public AjaxResult update(@RequestBody SysDictionary sysDictionary){
        return AjaxResult.success(sysDictionaryService.updateById(sysDictionary));
    }

    @ApiOperation("删除数据字典数据")
    @DeleteMapping("/{id}")
    public AjaxResult delete(@PathVariable Long id){
        return AjaxResult.success(sysDictionaryService.delDict(id));
    }

    @ApiOperation("根据id获取字典数据")
    @GetMapping("/{id}")
    public AjaxResult getById(@PathVariable Long id){
        return AjaxResult.success(sysDictionaryService.getById(id));
    }


}
