package com.zilber.boot.system.controller;

import com.zilber.boot.framework.web.service.SysLoginService;
import com.zilber.boot.framework.web.service.SysPermissionService;
import com.zilber.boot.system.pojo.SysMenu;
import com.zilber.boot.system.pojo.SysUser;
import com.zilber.boot.system.service.ISysMenuService;
import com.zilber.boot.utils.AjaxResult;
import com.zilber.boot.utils.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 登录验证
 *
 * @author lsc
 */
@RestController
@Api(tags = "用户登录")
public class SysLoginController {
    @Autowired
    private SysLoginService loginService;

    @Autowired
    private ISysMenuService menuService;

    @Autowired
    private SysPermissionService permissionService;

    @Value("${token.expireTime}")
    private int expireTime;
    /**
     * 登录方法
     *
     * @param sysUser 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    @ApiOperation(value="用户登录",notes="用户登录")
    public AjaxResult login(@RequestBody SysUser sysUser) {
        // 生成令牌
        String token = loginService.login(sysUser.getUserName(), sysUser.getPassword());
        Map rspMap=new HashMap<>();
        rspMap.put("access_token", token);
        rspMap.put("expires_in", expireTime);
        return AjaxResult.success(rspMap);
    }

    /**
     * 获取用户信息
     *
     * @return 用户信息
     */
    @GetMapping("getInfo")
    @ApiOperation(value="获取用户信息",notes="获取用户信息")
    public AjaxResult getInfo() {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        // 角色集合
        Set<String> roles = permissionService.getRolePermission(user);
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermission(user);
        Map ajax=new HashMap();
        ajax.put("user", user);
        ajax.put("roles", roles);
        ajax.put("permissions", permissions);
        return AjaxResult.success(ajax);
    }

    /**
     * 获取路由信息
     *
     * @return 路由信息
     */
    @GetMapping("getRouters")
    public AjaxResult getRouters()
    {
        Long userId = SecurityUtils.getUserId();
        List<SysMenu> menus = menuService.selectMenuTreeByUserId(userId);
        return AjaxResult.success(menuService.buildMenus(menus));
    }

}
